#!/usr/bin/python
# -*- coding: utf-8 -*-

from enum import Enum


class Language(Enum):
    """
    语言类型
    language
    """
    English = 0
    French = 1
    Spanish = 2
    Italian = 3
    Korean = 4
    Japanese = 5
    Simplified_Chinese = 6
